<?php

declare(strict_types=1);

namespace Drupal\ipd_validator\Plugin\Validator;

use Drupal\ipd_validator\ValidatorPluginBase;

/**
 * Plugin implementation of the Côte d'Ivoire CNI validator.
 *
 * @Validator(
 *   id = "ci_cni_validator",
 *   label = @Translation("Ivory Coast CNI"),
 *   description = @Translation("Must be 11 characters: 'C' + 10 digits or 'CI' + 9 digits."),
 *   country_code = "CI",
 *   active = true
 * )
 */
final class CiCniValidator extends ValidatorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function isValid(string $document): bool {
    // Uppercase for consistency.
    $document = strtoupper($document);

    // Match either:
    // - C followed by 10 digits
    // - CI followed by 9 digits.
    return preg_match('/^(C\d{10}|CI\d{9})$/', $document) === 1;
  }

}
