<?php

declare(strict_types=1);

namespace Drupal\ipd_validator\Plugin\Validator;

use Drupal\ipd_validator\ValidatorPluginBase;

/**
 * Plugin implementation of the India PAN validator.
 *
 * @Validator(
 *   id = "in_pan_validator",
 *   label = @Translation("India PAN"),
 *   description = @Translation("Must be 10 characters: 5 letters, 4 digits, 1 letter."),
 *   country_code = "IN",
 *   active = false
 * )
 */
final class InPanValidator extends ValidatorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function isValid(string $document): bool {
    // Convert to uppercase for consistency.
    $document = strtoupper($document);

    // PAN must be exactly 10 chars: 5 letters, 4 digits, 1 letter.
    if (!preg_match('/^[A-Z]{5}\d{4}[A-Z]$/', $document)) {
      return FALSE;
    }

    // Validate that the fourth character is valid.
    $fourthChar = $document[3];
    $validEntities = ['P', 'C', 'H', 'A', 'B', 'G', 'J', 'L', 'F', 'T'];

    return in_array($fourthChar, $validEntities, TRUE);
  }

}
