<?php

declare(strict_types=1);

namespace Drupal\ipd_validator\Plugin\Validator;

use Drupal\ipd_validator\ValidatorPluginBase;

/**
 * Plugin implementation of the Panama Cédula validator.
 *
 * @Validator(
 *   id = "pa_cedula_validator",
 *   label = @Translation("Panama Cedula de Identidad"),
 *   description = @Translation("Must be exactly 8 digits."),
 *   country_code = "PA",
 *   active = true
 * )
 */
final class PaCedulaValidator extends ValidatorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function isValid(string $document): bool {
    // Remove hyphens only (not all non-digits).
    $clean = str_replace(['-', ' ', '.'], '', $document);

    // Must be exactly 8 digits and nothing more.
    return preg_match('/^\d{8}$/', $clean) === 1;
  }

}
