<?php

declare(strict_types=1);

namespace Drupal\ipd_validator\Plugin\Validator;

use Drupal\ipd_validator\ValidatorPluginBase;

/**
 * Plugin implementation of the Paraguay CI validator.
 *
 * @Validator(
 *   id = "py_ci_validator",
 *   label = @Translation("Paraguay CI"),
 *   description = @Translation("Must be between 5 and 20 digits. Spaces and dots are removed."),
 *   country_code = "PY",
 *   active = true
 * )
 */
final class PyCiValidator extends ValidatorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function isValid(string $document): bool {
    // Clean spaces and dots (but not letters or other symbols).
    $clean = str_replace([' ', '.'], '', $document);

    // Allow only digits between 5 and 20 characters long.
    return preg_match('/^\d{5,20}$/', $clean) === 1;
  }

}
