<?php

declare(strict_types=1);

namespace Drupal\ipd_validator\Plugin\Validator;

use Drupal\ipd_validator\ValidatorPluginBase;

/**
 * Plugin implementation of the Zambia NRC validator.
 *
 * @Validator(
 *   id = "zm_nrc_validator",
 *   label = @Translation("Zambia National Registration Card"),
 *   description = @Translation("Must be exactly 9 numeric digits."),
 *   country_code = "ZM",
 *   active = true
 * )
 */
final class ZmNrcValidator extends ValidatorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function isValid(string $document): bool {
    // Remove hyphens, dots, spaces, and similar common separators.
    $clean = preg_replace('/[ \-\.]/', '', $document);

    // Validate that the cleaned string is exactly 9 digits.
    return preg_match('/^\d{9}$/', $clean) === 1;
  }

}
