<?php

declare(strict_types=1);

namespace Drupal\ipd_validator;

/**
 * Interface for validator plugins.
 */
interface ValidatorInterface {

  /**
   * Returns the translated plugin label.
   *
   * @return string
   *   Label.
   */
  public function label(): string;

  /**
   * Returns the translated plugin description.
   *
   * @return string
   *   Description.
   */
  public function description(): string;

  /**
   * Returns the validator country code.
   *
   * @return string
   *   Country code.
   */
  public function countryCode(): string;

  /**
   * Return the validator country label.
   *
   * @return string
   *   Country label.
   */
  public function country(): string;

  /**
   * Validate the document number.
   *
   * @return bool
   *   TRUE if the document is valid.
   */
  public function isValid(string $document): bool;

  /**
   * Fix document format.
   *
   * @param string $document
   *   Document.
   *
   * @return string
   *   Formatted document.
   */
  public function format(string $document): string;

  /**
   * Is this validator active?
   *
   * @return bool
   *   TRUE if is active. Default value TRUE.
   */
  public function isActive(): bool;

}
