<?php

declare(strict_types=1);

namespace Drupal\ipd_validator;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\Locale\CountryManager;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for validator plugins.
 */
abstract class ValidatorPluginBase extends PluginBase implements ValidatorInterface, ContainerFactoryPluginInterface {

  /**
   * Creates a Broken Block instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Locale\CountryManager $countryManager
   *   The country manager.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected readonly CountryManager $countryManager,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('country_manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    // Cast the label to a string since it is a TranslatableMarkup object.
    return (string) $this->pluginDefinition['title'];
  }

  /**
   * {@inheritdoc}
   */
  public function description(): string {
    // Cast the label to a string since it is a TranslatableMarkup object.
    return (string) $this->pluginDefinition['description'];
  }

  /**
   * {@inheritdoc}
   */
  public function countryCode(): string {
    return strtoupper($this->pluginDefinition['country_code']);
  }

  /**
   * {@inheritdoc}
   */
  public function country(): string {
    if (!empty($this->countryCode())) {
      return '';
    }
    $countries = $this->countryManager->getList();
    return $countries[$this->countryCode()] ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function isActive(): bool {
    return (bool) $this->pluginDefinition['active'];
  }

  /**
   * {@inheritdoc}
   */
  public function format(string $document): string {
    return $document;
  }

}
