<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\ArDniCuitCuilValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\ArDniCuitCuilValidator
 *
 * @group ipd_validator
 */
final class ArDniCuitCuilValidatorTest extends UnitTestCase {

  /**
   * The CountryManager mock.
   *
   * @var \Drupal\Core\Locale\CountryManager|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $countryManager;

  /**
   * The ArDniCuitCuilValidator validator instance.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\ArDniCuitCuilValidator
   */
  protected ArDniCuitCuilValidator $validator;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Mock CountryManager
    // (not needed in this test but required in constructor).
    $this->countryManager = $this->createMock(CountryManager::class);

    // Create the validator instance with the required dependencies.
    $this->validator = new ArDniCuitCuilValidator(
      [],
      'ar_dni_cuit_cuil_validator',
      ['country_code' => 'AR'],
      $this->countryManager
    );
  }

  /**
   * Test the document validation by using data providers.
   *
   * @param string $document
   *   The document number to be validated.
   * @param bool $expected
   *   The expected validation result.
   *
   * @covers ::isValid
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides a dataset of valid and invalid document numbers.
   *
   * @return array
   *   A list of [document, expected_result] pairs.
   */
  public function documentProvider(): array {
    return [
      // ✅ Valid DNI (7-9 digits)
      ['1234567', TRUE],
      ['12345678', TRUE],
      ['123456789', TRUE],

      // ✅ Valid CUIT/CUIL (11 digits)
      ['20345678901', TRUE],
      ['27345678901', TRUE],

      // ❌ Invalid cases
    // Too short.
      ['123456', FALSE],
    // Too long.
      ['123456789012', FALSE],
    // Contains letters.
      ['ABC1234567', FALSE],
    // Contains mixed characters.
      ['1234A5678B', FALSE],
    // 10 digits (incorrect structure)
      ['1234567890', FALSE],
    // Empty string.
      ['', FALSE],
    // Completely non-numeric.
      ['abcdefghijk', FALSE],
    ];
  }

}
