<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\BoCiValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\BoCiValidator
 *
 * @group ipd_validator
 */
final class BoCiValidatorTest extends UnitTestCase {

  /**
   * The CountryManager mock.
   *
   * @var \Drupal\Core\Locale\CountryManager|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $countryManager;

  /**
   * The BoCiValidator instance.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\BoCiValidator
   */
  protected BoCiValidator $validator;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Mock CountryManager (required for ValidatorPluginBase).
    $this->countryManager = $this->createMock(CountryManager::class);

    // Create an instance of the validator.
    $this->validator = new BoCiValidator(
      [],
      'bo_ci_validator',
      ['country_code' => 'BO'],
      $this->countryManager
    );
  }

  /**
   * Test the document validation using a data provider.
   *
   * @param string $document
   *   The document number to be validated.
   * @param bool $expected
   *   The expected validation result.
   *
   * @covers ::isValid
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides a dataset of valid and invalid Bolivia CI numbers.
   *
   * @return array
   *   A list of [document, expected_result] pairs.
   */
  public function documentProvider(): array {
    return [
      // ✅ Valid CI (5-20 digits)
    // 5 digits
      ['12345', TRUE],
    // 12 digits
      ['123456789012', TRUE],
    // 20 digits (max)
      ['12345678901234567890', TRUE],

      // ❌ Invalid cases
    // Too short (4 digits)
      ['1234', FALSE],
    // Too long (21 digits)
      ['123456789012345678901', FALSE],
    // Contains letters.
      ['ABC12345', FALSE],
    // Mixed alphanumeric.
      ['1234A567890', FALSE],
    // Completely non-numeric.
      ['abcd', FALSE],
    // Empty string.
      ['', FALSE],
    ];
  }

}
