<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\BrCpfCnpjValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\BrCpfCnpjValidator
 *
 * @group ipd_validator
 */
final class BrCpfCnpjValidatorTest extends UnitTestCase {

  /**
   * The CountryManager mock.
   *
   * @var \Drupal\Core\Locale\CountryManager|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $countryManager;

  /**
   * The BrCpfCnpjValidator instance.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\BrCpfCnpjValidator
   */
  protected BrCpfCnpjValidator $validator;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Mock CountryManager (required for ValidatorPluginBase).
    $this->countryManager = $this->createMock(CountryManager::class);

    // Create an instance of the validator.
    $this->validator = new BrCpfCnpjValidator(
      [],
      'br_cpf_cnpj_validator',
      ['country_code' => 'BR'],
      $this->countryManager
    );
  }

  /**
   * Test the document validation using a data provider.
   *
   * @param string $document
   *   The document number to be validated.
   * @param bool $expected
   *   The expected validation result.
   *
   * @covers ::isValid
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides a dataset of valid and invalid CPF/CNPJ numbers.
   *
   * @return array
   *   A list of [document, expected_result] pairs.
   */
  public function documentProvider(): array {
    return [
      // ✅ Valid CPFs (11 digits)
    // Valid CPF.
      ['52998224725', TRUE],
    // Valid CPF (incorrect check digits)
      ['12345678909', TRUE],
    // Repeating numbers.
      ['11111111111', FALSE],

      // ✅ Valid CNPJs (14 digits)
    // Valid CNPJ.
      ['11444777000161', TRUE],
    // Valid CNPJ (incorrect check digits)
      ['11222333000181', TRUE],
    // Repeating numbers.
      ['00000000000000', FALSE],

      // ❌ Invalid cases
    // Too short (10 digits)
      ['5299822472', FALSE],
    // Incorrect CPF check digit.
      ['529982247259', FALSE],
    // Contains letters.
      ['ABC1234567890', FALSE],
    // Too short.
      ['12345678', FALSE],
    // Empty string.
      ['', FALSE],
    ];
  }

}
