<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\CiCniValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\CiCniValidator
 *
 * @group ipd_validator
 */
final class CiCniValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\CiCniValidator
   */
  protected CiCniValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new CiCniValidator(
      [],
      'ci_cni_validator',
      ['country_code' => 'CI'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
    // C + 10 digits.
      ['C1234567890', TRUE],
    // CI + 9 digits.
      ['CI123456789', TRUE],
    // Lowercase converted.
      ['ci123456789', TRUE],

      // ❌ Inválidos
    // Solo números.
      ['12345678901', FALSE],
    // Letra diferente.
      ['D1234567890', FALSE],
    // Muy corto.
      ['CI12345678', FALSE],
    // 1 dígito menos
      ['C123456789', FALSE],
    // Muy largo.
      ['CI1234567890', FALSE],
    // Letras en lugar de dígitos.
      ['C12345678AB', FALSE],
    // Letra final.
      ['CI12345678A', FALSE],
    // vacío.
      ['', FALSE],
    ];
  }

}
