<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\ClCiRutValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\ClCiRutValidator
 *
 * @group ipd_validator
 */
final class ClCiRutValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\ClCiRutValidator
   */
  protected ClCiRutValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new ClCiRutValidator(
      [],
      'cl_ci_rut_validator',
      ['country_code' => 'CL'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    // Online validator: https://validarutchile.cl/.
    return [
      // ✅ Valid RUTs (with correct verifier digits)
      ['12.345.678-5', TRUE],
      ['12345678-5', TRUE],
      ['11111111-1', TRUE],
      ['12345678-5', TRUE],
    // Missing hyphen, though accepted, valid check digit.
      ['123456785', TRUE],

      // ❌ Incorrect check digit
      ['9.876.543-K', FALSE],
      ['9876543-k', FALSE],
      ['12267433-3', FALSE],
      ['12345678-4', FALSE],
      ['9876543-1', FALSE],
      ['11111111-2', FALSE],

      // ❌ Format problems
    // Very short.
      ['1234567', FALSE],
    // Only letters.
      ['abcdefgh-i', FALSE],
    // Invalid character.
      ['12345678#5', FALSE],
    // Empty.
      ['', FALSE],
    ];
  }

}
