<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\CmCniValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\CmCniValidator
 *
 * @group ipd_validator
 */
final class CmCniValidatorTest extends UnitTestCase {

  /**
   * The CountryManager mock.
   *
   * @var \Drupal\Core\Locale\CountryManager|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $countryManager;

  /**
   * The CmCniValidator instance.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\CmCniValidator
   */
  protected CmCniValidator $validator;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);
    $this->validator = new CmCniValidator(
      [],
      'cm_cni_validator',
      ['country_code' => 'CM'],
      $this->countryManager
    );
  }

  /**
   * Tests document validation using different cases.
   *
   * @param string $document
   *   The document to validate.
   * @param bool $expected
   *   Expected result.
   *
   * @covers ::isValid
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides valid and invalid Cameroon CNI numbers.
   *
   * @return array
   *   An array of [document, expected_result] pairs.
   */
  public function documentProvider(): array {
    return [
      // ✅ Valid
      ['12345678', TRUE],
      ['00001234', TRUE],

      // ❌ Invalid
    // Too short.
      ['1234567', FALSE],
    // Too long.
      ['123456789', FALSE],
    // Contains letter.
      ['A2345678', FALSE],
    // Contains symbol.
      ['1234-567', FALSE],
    // Empty.
      ['', FALSE],
    // Invalid characters.
      ['abcdefgh', FALSE],
    ];
  }

}
