<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\CnIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\CnIdValidator
 *
 * @group ipd_validator
 */
final class CnIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The document validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\CnIdValidator
   */
  protected CnIdValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new CnIdValidator(
      [],
      'cn_id_validator',
      ['country_code' => 'CN'],
      $this->countryManager
    );
  }

  /**
   * Test document validation.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    // Online validator: https://toolbox.tinkink.net/tools/id-validator
    return [
      // ✅ Valid Chinese Citizen IDs (based on correct checksum)
      ['11010519491231002X', TRUE],
      ['360731199309191278', TRUE],
      ['110101199003070070', TRUE],
      ['123456789012345677', TRUE],
      ['210102198617083111', TRUE],

      // ❌ Invalid checksum
      ['11010119900307007X', FALSE],
      ['21010219861708311X', FALSE],
      ['110105194912310028', FALSE],
      ['360731199309191279', FALSE],
      ['210102198617083112', FALSE],

      // ❌ Invalid format
    // Lowercase x is made uppercase internally.
      ['11010519491231002x', TRUE],
    // Too short.
      ['1101051949123100X', FALSE],
    // All letters.
      ['abcdefghijabcdefgh', FALSE],
    // Too long.
      ['1234567890123456789', FALSE],
      ['', FALSE],
    ];
  }

}
