<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\CoCcValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\CoCcValidator
 *
 * @group ipd_validator
 */
final class CoCcValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\CoCcValidator
   */
  protected CoCcValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new CoCcValidator(
      [],
      'co_cc_validator',
      ['country_code' => 'CO'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    // Online validator:
    // https://blog.adres-gov.com/calcular-digito-verificacion-dian/
    return [
      // ✅ Valid Colombian CCs
    // Minimum length.
      ['123456', TRUE],
    // 10 digits
      ['1001234567', TRUE],
    // Max 11 digits.
      ['99999999999', TRUE],

      // ❌ Invalid cases
    // Too short.
      ['12345', FALSE],
    // Too long.
      ['123456789012', FALSE],
    // Letters.
      ['ABC123456', FALSE],
    // Dot formatting.
      ['123.456.789', FALSE],
    // Symbols.
      ['123456-789', FALSE],
    // Empty.
      ['', FALSE],
    ];
  }

}
