<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\EcCiValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\EcCiValidator
 *
 * @group ipd_validator
 */
final class EcCiValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\GhGhanaCardValidator
   */
  protected EcCiValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new EcCiValidator(
      [],
      'ec_ci_validator',
      ['country_code' => 'EC'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos (5-20 dígitos)
      ['12345', TRUE],
      ['0123456789', TRUE],
    // 20 dígitos
      ['12345678901234567890', TRUE],

      // ❌ Inválidos
    // Muy corto.
      ['1234', FALSE],
    // Muy largo (21)
      ['123456789012345678901', FALSE],
    // Letras.
      ['ABC123456', FALSE],
    // Guiones.
      ['123-456-789', FALSE],
    // Punto.
      ['123.456.789', FALSE],
    // Vacío.
      ['', FALSE],
    ];
  }

}
