<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\EgIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\EgIdValidator
 *
 * @group ipd_validator
 */
final class EgIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\EgIdValidator
   */
  protected EgIdValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new EgIdValidator(
      [],
      'eg_id_validator',
      ['country_code' => 'EG'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['29805211234567', TRUE],
      ['29901010101010', TRUE],
      ['30012345678901', TRUE],

      // ❌ Inválidos
    // 13 dígitos
      ['1234567890123', FALSE],
    // 15 dígitos
      ['123456789012345', FALSE],
    // Letras.
      ['abcdefghijklmno', FALSE],
    // Con guiones.
      ['1234-5678-9012-34', FALSE],
    // Vacío.
      ['', FALSE],
    ];
  }

}
