<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\GhGhanaCardValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\GhGhanaCardValidator
 *
 * @group ipd_validator
 */
final class GhGhanaCardValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\GhGhanaCardValidator
   */
  protected GhGhanaCardValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new GhGhanaCardValidator(
      [],
      'gh_ghana_card_validator',
      ['country_code' => 'GH'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['GHA1234567890', TRUE],
      ['ABC9876543210', TRUE],
    // Con letras minúsculas.
      ['ghz0000000000', TRUE],

      // ❌ Inválidos
    // Solo 2 letras.
      ['GH1234567890', FALSE],
    // Solo 9 números.
      ['GHA123456789', FALSE],
    // 11 números.
      ['GHA12345678901', FALSE],
    // Letras en medio.
      ['123GHA4567890', FALSE],
    // Último caracter alfabético.
      ['GHA12345678A', FALSE],
    // Caracter especial.
      ['GHA-1234567890', FALSE],
    // Vacío.
      ['', FALSE],
    ];
  }

}
