<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\HnDniValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\HnDniValidator
 *
 * @group ipd_validator
 */
final class HnDniValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\HnDniValidator
   */
  protected HnDniValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new HnDniValidator(
      [],
      'hn_dni_validator',
      ['country_code' => 'HN'],
      $this->countryManager
    );
  }

  /**
   * Test the document validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['0801198512345', TRUE],
      ['0000000000000', TRUE],
      ['1234567890123', TRUE],

      // ❌ Inválidos
    // 12 dígitos
      ['123456789012', FALSE],
    // 14 dígitos
      ['12345678901234', FALSE],
    // Con letras.
      ['DNI1234567890', FALSE],
    // Con guiones.
      ['1234-5678-9012', FALSE],
    // Vacío.
      ['', FALSE],
      ['abcdefghijklm', FALSE],
    ];
  }

}
