<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\IdNikValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\IdNikValidator
 *
 * @group ipd_validator
 */
final class IdNikValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\IdNikValidator
   */
  protected IdNikValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new IdNikValidator(
      [],
      'id_nik_validator',
      ['country_code' => 'ID'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['3203011201980003', TRUE],
      ['0000000000000001', TRUE],
      ['9999999999999999', TRUE],

      // ❌ Inválidos
      // 15 dígitos.
      ['123456789012345', FALSE],
      // 17 dígitos.
      ['12345678901234567', FALSE],
      // Letras incluidas.
      ['3203A11201980003', FALSE],
      // Guiones.
      ['3203-0112-01980003', FALSE],
      // Vacío.
      ['', FALSE],
    ];
  }

}
