<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\InPanValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\InPanValidator
 *
 * @group ipd_validator
 */
final class InPanValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\InPanValidator
   */
  protected InPanValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new InPanValidator(
      [],
      'in_pan_validator',
      ['country_code' => 'IN'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->markTestSkipped('Este test se omite por no tener valores correctos para probarlo.');
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['ABCDE1234F', TRUE],
    // Lower case input (should be accepted)
      ['abcde1234f', TRUE],
      ['PQRST6789Z', TRUE],

      // ❌ Inválidos
    // Termina en número.
      ['ABCDE12345', FALSE],
    // Empieza con números.
      ['1234512345', FALSE],
    // 11 caracteres.
      ['ABCDE12345F', FALSE],
    // 4 letras al inicio
      ['ABCD1234F', FALSE],
    // Solo 3 números.
      ['ABCDE123F', FALSE],
    // Falta letra final.
      ['ABCDE1234', FALSE],
    // símbolo no válido.
      ['ABCDE@234F', FALSE],
    // Espacio.
      ['ABCDE 1234F', FALSE],
    // vacío.
      ['', FALSE],
    ];
  }

}
