<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\JoIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\JoIdValidator
 *
 * @group ipd_validator
 */
final class JoIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\JoIdValidator
   */
  protected JoIdValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new JoIdValidator(
      [],
      'jo_id_validator',
      ['country_code' => 'JO'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides Jordan ID test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['1234567890', TRUE],
      ['0000000001', TRUE],
      ['9999999999', TRUE],

      // ❌ Inválidos
      // 9 dígitos
      ['123456789', FALSE],
      // 11 dígitos
      ['12345678901', FALSE],
      // Letras al final.
      ['123456789A', FALSE],
      // Letras al inicio.
      ['A123456789', FALSE],
      // Vacío.
      ['', FALSE],
      // Guiones.
      ['123-456-7890', FALSE],
    ];
  }

}
