<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\JpMyNumberValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\JpMyNumberValidator
 *
 * @group ipd_validator
 */
final class JpMyNumberValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\JpMyNumberValidator
   */
  protected JpMyNumberValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new JpMyNumberValidator(
      [],
      'jp_my_number_validator',
      ['country_code' => 'JP'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides valid and invalid documents.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['123456789012', TRUE],
      ['000000000001', TRUE],
      ['999999999999', TRUE],

      // ❌ Inválidos
    // 11 digits
      ['12345678901', FALSE],
    // 13 digits
      ['1234567890123', FALSE],
    // Ends with letter.
      ['12345678901A', FALSE],
    // full-width digits (unicode)
      ['１２３４５６７８９０１２', FALSE],
    // Hyphens.
      ['1234-5678-9012', FALSE],
    // Empty.
      ['', FALSE],
    ];
  }

}
