<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\KeIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\KeIdValidator
 *
 * @group ipd_validator
 */
final class KeIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\KeIdValidator
   */
  protected KeIdValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new KeIdValidator(
      [],
      'ke_id_validator',
      ['country_code' => 'KE'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides Kenya ID test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['12345678', TRUE],
      ['00000001', TRUE],
      ['99999999', TRUE],

      // ❌ Inválidos
      // 7 dígitos
      ['1234567', FALSE],
      // 9 dígitos
      ['123456789', FALSE],
      // Letras.
      ['A2345678', FALSE],
      // Guiones.
      ['1234-5678', FALSE],
      // Vacío.
      ['', FALSE],
      // Alfanumérico.
      ['1234ABCD', FALSE],
    ];
  }

}
