<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\MaCnieValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\MaCnieValidator
 *
 * @group ipd_validator
 */
final class MaCnieValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\MaCnieValidator
   */
  protected MaCnieValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new MaCnieValidator(
      [],
      'ma_cnie_validator',
      ['country_code' => 'MA'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides test cases for CNIE.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['AB123', TRUE],
      ['123456789', TRUE],
      ['L000000000123', TRUE],
    // 19 caracteres
      ['M4R0CC0923AB123XYZ', TRUE],

      // ❌ Inválidos
    // Demasiado corto.
      ['1234', FALSE],
    // 21 caracteres
      ['AB12345678901234567890', FALSE],
    // guión bajo.
      ['AB_123', FALSE],
    // carácter especial.
      ['AB123#456', FALSE],
    // Espacios.
      ['   ', FALSE],
      ['', FALSE],
    ];
  }

}
