<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\MxCurpValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\MxCurpValidator
 *
 * @group ipd_validator
 */
final class MxCurpValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\MxCurpValidator
   */
  protected MxCurpValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new MxCurpValidator(
      [],
      'mx_curp_validator',
      ['country_code' => 'MX'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides CURP test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos (alfaNum, entre 10 y 18 caracteres)
      ['GODE561231HDFABC09', TRUE],
      ['MABC920101MDFLRS07', TRUE],
    // 10 caracteres
      ['XYZ1234567', TRUE],
    // 18 caracteres
      ['ABC123456789012345', TRUE],
    // 15 caracteres
      ['GODE561231HDFAB', TRUE],

      // ❌ Inválidos
    // 9 caracteres
      ['GODE56123', FALSE],
    // 19 caracteres
      ['GODE561231HDFABC0912', FALSE],
    // carácter inválido.
      ['gode561231#dfabc09', FALSE],
    // guión.
      ['1234567890-', FALSE],
    // vacío.
      ['', FALSE],
    ];
  }

}
