<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\MyNricValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\MyNricValidator
 *
 * @group ipd_validator
 */
final class MyNricValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\MyNricValidator
   */
  protected MyNricValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new MyNricValidator(
      [],
      'my_nric_validator',
      ['country_code' => 'MY'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides Malaysia NRIC test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['900101145521', TRUE],
      ['010203070809', TRUE],
      ['000000000000', TRUE],

      // ❌ Inválidos
      // 11 dígitos
      ['12345678901', FALSE],
      // 13 dígitos
      ['1234567890123', FALSE],
      // Con letras.
      ['90010114A521', FALSE],
      // Formato con guiones.
      ['900101-14-5521', FALSE],
      // Espacios.
      ['900101 145521', FALSE],
      // Vacío.
      ['', FALSE],
    ];
  }

}
