<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\NeCniValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\NeCniValidator
 *
 * @group ipd_validator
 */
final class NeCniValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\NeCniValidator
   */
  protected NeCniValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new NeCniValidator(
      [],
      'ne_cni_validator',
      ['country_code' => 'NE'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides Niger CNI test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['1234567', TRUE],
      ['0000001', TRUE],
      ['9999999', TRUE],

      // ❌ Inválidos
    // 6 dígitos
      ['123456', FALSE],
    // 8 dígitos
      ['12345678', FALSE],
    // Letra al inicio.
      ['A234567', FALSE],
    // Letra en medio.
      ['12345A7', FALSE],
    // símbolo.
      ['123456&', FALSE],
    // Guion.
      ['123-456', FALSE],
    // vacío.
      ['', FALSE],
    // Espacios.
      ['       ', FALSE],
    ];
  }

}
