<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\NgNinValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\NgNinValidator
 *
 * @group ipd_validator
 */
final class NgNinValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\NgNinValidator
   */
  protected NgNinValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new NgNinValidator(
      [],
      'ng_nin_validator',
      ['country_code' => 'NG'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides Nigeria NIN test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['12345678901', TRUE],
      ['00000000000', TRUE],
      ['99999999999', TRUE],

      // ❌ Inválidos
    // 10 caracteres
      ['1234567890', FALSE],
    // 12 caracteres
      ['123456789012', FALSE],
    // Letra al final.
      ['1234567890A', FALSE],
    // Letra al inicio.
      ['A2345678901', FALSE],
    // símbolo.
      ['1234-5678901', FALSE],
      ['', FALSE],
      ['           ', FALSE],
    ];
  }

}
