<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\NiDniValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\NiDniValidator
 *
 * @group ipd_validator
 */
final class NiDniValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\NiDniValidator
   */
  protected NiDniValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new NiDniValidator(
      [],
      'ni_dni_validator',
      ['country_code' => 'NI'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides test cases for NI DNI.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['0012312345678M', TRUE],
      ['1234567890123A', TRUE],
    // Letra minúscula aceptada.
      ['0000000000000z', TRUE],

      // ❌ Inválidos
      // Menos dígitos
    // 12+1 = 13 chars
      ['123456789012A', FALSE],
      // Más dígitos
    // 14+1 = 15 chars.
      ['12345678901234A', FALSE],
      // Letra en el medio.
      ['12345678901A34', FALSE],
      // Termina en un número.
      ['12345678901234', FALSE],
      // Guiones u otros símbolos.
      ['1234-567890123Z', FALSE],
      // Vacío.
      ['', FALSE],
    ];
  }

}
