<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\PaCedulaValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\PaCedulaValidator
 *
 * @group ipd_validator
 */
final class PaCedulaValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\PaCedulaValidator
   */
  protected PaCedulaValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new PaCedulaValidator(
      [],
      'pa_cedula_validator',
      ['country_code' => 'PA'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides Panama cedula test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['12345678', TRUE],
      ['00000001', TRUE],
      ['87654321', TRUE],
      ['1234-5678', TRUE],
      ['12 34 56 78', TRUE],
      ['123.456.78', TRUE],
      ['123 456-78', TRUE],
    // símbolo.
      ['12-345678', TRUE],

      // ❌ Inválidos
    // 7 dígitos
      ['1234567', FALSE],
    // 9 dígitos
      ['123456789', FALSE],
    // Letra al inicio.
      ['A2345678', FALSE],
    // Letra en medio.
      ['1234A678', FALSE],
    // Letra al final.
      ['12345678Z', FALSE],
      ['', FALSE],
    ];
  }

}
