<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\PeDniValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\PeDniValidator
 *
 * @group ipd_validator
 */
final class PeDniValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected PeDniValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new PeDniValidator(
      [],
      'pe_dni_validator',
      ['country_code' => 'PE'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['12345678', TRUE],
      ['00000001', TRUE],
      ['123456789', TRUE],

      // ❌ Inválidos
    // 7 dígitos
      ['1234567', FALSE],
    // 10 dígitos
      ['1234567890', FALSE],
    // Espacio.
      ['12 345678', FALSE],
    // Letras.
      ['ABC456789', FALSE],
    // guión.
      ['1234-5678', FALSE],
    // Punto.
      ['1234.5678', FALSE],
    // vacío.
      ['', FALSE],
    ];
  }

}
