<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\PhPsnValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\PhPsnValidator
 *
 * @group ipd_validator
 */
final class PhPsnValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected PhPsnValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new PhPsnValidator(
      [],
      'ph_psn_validator',
      ['country_code' => 'PH'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['123456789012', TRUE],
      ['000000000001', TRUE],
      ['999999999999', TRUE],

      // ❌ Inválidos
    // 11 dígitos
      ['12345678901', FALSE],
    // 13 dígitos
      ['1234567890123', FALSE],
    // Espacio.
      ['12 3456789012', FALSE],
    // Guiones.
      ['1234-56789012', FALSE],
    // Letras.
      ['PH1234567890', FALSE],
    // Termina en letra.
      ['12345678901A', FALSE],
      ['', FALSE],
    ];
  }

}
