<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\PkCnicValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\PkCnicValidator
 *
 * @group ipd_validator
 */
final class PkCnicValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\PkCnicValidator
   */
  protected PkCnicValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new PkCnicValidator(
      [],
      'pk_cnic_validator',
      ['country_code' => 'PK'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides Pakistan CNIC test cases.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['3520222222222', TRUE],
      ['0000000000001', TRUE],
      ['9999999999999', TRUE],

      // ❌ Inválidos
    // 12 dígitos
      ['123456789012', FALSE],
    // 14 dígitos
      ['12345678901234', FALSE],
    // Letra en medio.
      ['35202A2222222', FALSE],
    // símbolo.
      ['35202@2222222', FALSE],
    // Espacio.
      ['35202 2222222', FALSE],
    // Con guiones (formato oficial, pero inválido aquí)
      ['35202-2222222-1', FALSE],
      ['', FALSE],
    ];
  }

}
