<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\PyCiValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\PyCiValidator
 *
 * @group ipd_validator
 */
final class PyCiValidatorTest extends UnitTestCase {

  /**
   * The country manager mock.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator under test.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\PyCiValidator
   */
  protected PyCiValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new PyCiValidator(
      [],
      'py_ci_validator',
      ['country_code' => 'PY'],
      $this->countryManager
    );
  }

  /**
   * Test the validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides test data.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos (limpios o con espacios/puntos)
      ['123456', TRUE],
    // 20 digits
      ['00123456789012345678', TRUE],
      ['12 345 678', TRUE],
      ['1.234.567.890', TRUE],
      ['00000', TRUE],

      // ❌ Inválidos
    // Too short (4 digits)
      ['1234', FALSE],
    // Too long (21 digits)
      ['123456789012345678901', FALSE],
    // Contains letter.
      ['12.34A678', FALSE],
    // Symbol.
      ['1 2 3 4!5 6', FALSE],
    // Hyphen not allowed.
      ['12-345678', FALSE],
    // Empty.
      ['', FALSE],
    ];
  }

}
