<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\RwIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\RwIdValidator
 *
 * @group ipd_validator
 */
final class RwIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected RwIdValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new RwIdValidator(
      [],
      'rw_id_validator',
      ['country_code' => 'RW'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['1234567890123456', TRUE],
      ['0000000000000000', TRUE],
      ['9999999999999999', TRUE],

      // ❌ Inválidos
    // 15 dígitos
      ['123456789012345', FALSE],
    // 17 dígitos
      ['12345678901234567', FALSE],
    // Letra en medio.
      ['12345678901234A6', FALSE],
    // Letra final.
      ['119876543210123X', FALSE],
    // Espacio.
      ['11 98765432101234', FALSE],
    // Guiones.
      ['1198-765432-101234', FALSE],
      ['', FALSE],
    ];
  }

}
