<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\SaIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\SaIdValidator
 *
 * @group ipd_validator
 */
final class SaIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected SaIdValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new SaIdValidator(
      [],
      'sa_id_validator',
      ['country_code' => 'SA'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['1234567890', TRUE],
      ['1000000001', TRUE],
      ['0000000000', TRUE],

      // ❌ Inválidos
    // 9 dígitos
      ['123456789', FALSE],
    // 11 dígitos
      ['12345678901', FALSE],
    // Letra al final.
      ['112345678A', FALSE],
    // Letra al inicio.
      ['A123456789', FALSE],
    // Guiones.
      ['12345-6789', FALSE],
    // Espacio.
      ['12345 67890', FALSE],
      ['', FALSE],
    ];
  }

}
