<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\SnCniValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\SnCniValidator
 *
 * @group ipd_validator
 */
final class SnCniValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected SnCniValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new SnCniValidator(
      [],
      'sn_cni_validator',
      ['country_code' => 'SN'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
    // 13 digits
      ['1234567890123', TRUE],
    // 14 digits
      ['12345678901234', TRUE],
    // 17 digits
      ['12345678901234567', TRUE],
    // All zeros, valid length.
      ['00000000000000000', TRUE],

      // ❌ Inválidos
    // 12 digits
      ['123456789012', FALSE],
    // 18 digits
      ['123456789012345678', FALSE],
    // Letter in the middle.
      ['12345678901A345', FALSE],
    // Contains hyphen.
      ['1234-56789012345', FALSE],
    // Contains spaces.
      ['1234 5678 9012 34', FALSE],
    // Empty.
      ['', FALSE],
    ];
  }

}
