<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\SvDuiValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\SvDuiValidator
 *
 * @group ipd_validator
 */
final class SvDuiValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\GhGhanaCardValidator
   */
  protected SvDuiValidator $validator;

  /**
   * Setup test.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new SvDuiValidator(
      [],
      'sv_dui_validator',
      ['country_code' => 'SV'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['123456789', TRUE],
      ['000000001', TRUE],

      // ❌ Inválidos
    // 8 dígitos
      ['12345678', FALSE],
    // 10 dígitos
      ['1234567890', FALSE],
    // Formato con guion.
      ['1234-5678', FALSE],
    // Letras.
      ['ABC123456', FALSE],
    // Vacío.
      ['', FALSE],
    // Punto.
      ['12345.678', FALSE],
    ];
  }

}
