<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\ThIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\ThIdValidator
 *
 * @group ipd_validator
 */
final class ThIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected ThIdValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new ThIdValidator(
      [],
      'th_id_validator',
      ['country_code' => 'TH'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    // Online validator:
    // https://globalidcheck.com/es/verify/thailand-idnr
    return [
      // ✅ Válidos con dígito verificador Mod 11 correcto
      ['1101700203451', FALSE],
      ['3101701452131', TRUE],
    // válido por cálculo.
      ['1234567890128', FALSE],

      // ❌ Inválidos
    // Mal verificador.
      ['1101700203452', FALSE],
    // Buen formato, mal verificador.
      ['1234567890123', FALSE],
    // Corto.
      ['110170020345', FALSE],
    // Largo.
      ['11017002034511', FALSE],
    // Letra.
      ['11017002A3451', FALSE],
    // Guiones.
      ['1101-7002-03451', FALSE],
      ['', FALSE],
    ];
  }

}
