<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\TrKimlikValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\TrKimlikValidator
 *
 * @group ipd_validator
 */
final class TrKimlikValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected TrKimlikValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new TrKimlikValidator(
      [],
      'tr_kimlik_validator',
      ['country_code' => 'TR'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['12345', TRUE],
      ['12345678901', TRUE],
    // 20 dígitos
      ['99999999999999999999', TRUE],

      // ❌ Inválidos
    // 4 dígitos
      ['1234', FALSE],
    // 21 dígitos
      ['123456789012345678901', FALSE],
    // Letra.
      ['12345A7890', FALSE],
    // guión.
      ['1234-56789', FALSE],
    // Espacio.
      ['12 34567890', FALSE],
      ['', FALSE],
    ];
  }

}
