<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\TzIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\TzIdValidator
 *
 * @group ipd_validator
 */
final class TzIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected TzIdValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new TzIdValidator(
      [],
      'tz_id_validator',
      ['country_code' => 'TZ'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['12345678901234567890', TRUE],
      ['00000000000000000000', TRUE],
      ['99999999999999999999', TRUE],

      // ❌ Inválidos
    // 19 dígitos
      ['1234567890123456789', FALSE],
    // 21 dígitos
      ['123456789012345678901', FALSE],
    // Letra.
      ['12345678901234567X90', FALSE],
    // Guiones.
      ['1234-5678901234567890', FALSE],
    // Espacios.
      ['1234 5678 9012 3456 7890', FALSE],
      ['', FALSE],
    ];
  }

}
