<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\UgNicValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\UgNicValidator
 *
 * @group ipd_validator
 */
final class UgNicValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected UgNicValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new UgNicValidator(
      [],
      'ug_nic_validator',
      ['country_code' => 'UG'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Provides test cases for Uganda NIC.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
    // 14 digits
      ['12345678901234', TRUE],
    // 16 digits
      ['9876543210987654', TRUE],
    // 17 digits
      ['12345678901234567', TRUE],

      // ❌ Inválidos
    // 13 digits
      ['1234567890123', FALSE],
    // 18 digits
      ['123456789012345678', FALSE],
    // Letter at end.
      ['1234567890123A', FALSE],
    // Symbols.
      ['1234-5678-9012-34', FALSE],
    // Spaces.
      ['1234 5678 901234', FALSE],
      ['', FALSE],
    ];
  }

}
