<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\UyCiRutValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\UyCiRutValidator
 *
 * @group ipd_validator
 */
final class UyCiRutValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected UyCiRutValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new UyCiRutValidator(
      [],
      'uy_ci_rut_validator',
      ['country_code' => 'UY'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos – CI
      ['123456', TRUE],
      ['1234567', TRUE],
      ['12345678', TRUE],

      // ✅ Válido – RUT
      ['123456789012', TRUE],

      // ❌ Inválidos
    // Menos de 6.
      ['12345', FALSE],
    // 9 dígitos
      ['123456789', FALSE],
    // 11 dígitos
      ['12345678901', FALSE],
    // 13 dígitos
      ['1234567890123', FALSE],
    // Letra.
      ['1234A678', FALSE],
    // Punto.
      ['12.345678', FALSE],
    // guión.
      ['1234-56789', FALSE],
      ['', FALSE],
    ];
  }

}
