<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\VnVnidValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
 *
 * @group ipd_validator
 */
final class VnVnidValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected VnVnidValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new VnVnidValidator(
      [],
      'vn_vnid_validator',
      ['country_code' => 'VN'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['123456789', TRUE],
      ['000000001', TRUE],
      ['1234567890123', TRUE],
      ['0000000000001', TRUE],

      // ❌ Inválidos
    // 8 dígitos
      ['12345678', FALSE],
    // 10 dígitos
      ['1234567890', FALSE],
    // Letra.
      ['12345678A', FALSE],
    // Guion.
      ['1234-567890', FALSE],
    // Espacio.
      ['123 456 789', FALSE],
    // 14 dígitos.
      ['12345678901234', FALSE],
      ['', FALSE],
    ];
  }

}
