<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\ZaIdValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\ZaIdValidator
 *
 * @group ipd_validator
 */
final class ZaIdValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected ZaIdValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();
    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new ZaIdValidator(
      [],
      'za_id_validator',
      ['country_code' => 'ZA'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->markTestSkipped('Este test se omite por no tener valores correctos para probarlo.');
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos (con dígito de control correcto)
      ['8001015009087', TRUE],
      ['9901010142086', TRUE],
      ['0002295029087', TRUE],

      // ❌ Inválidos (fallo en Luhn o formato)
    // Dígito de control incorrecto.
      ['8001015009088', FALSE],
    // Dígito mal calculado.
      ['9901010142087', FALSE],
    // 12 dígitos.
      ['123456789012', FALSE],
    // 14 dígitos
      ['12345678901234', FALSE],
    // Contiene letra.
      ['12345678A0123', FALSE],
    // Vacío.
      ['', FALSE],
    ];
  }

}
