<?php

declare(strict_types=1);

namespace Drupal\Tests\ipd_validator\Unit\Plugin\Validator;

use Drupal\Core\Locale\CountryManager;
use Drupal\ipd_validator\Plugin\Validator\ZmNrcValidator;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\ipd_validator\Plugin\Validator\ZmNrcValidator
 *
 * @group ipd_validator
 */
final class ZmNrcValidatorTest extends UnitTestCase {

  /**
   * The country manager.
   *
   * @var \Drupal\Core\Locale\CountryManager
   */
  protected $countryManager;

  /**
   * The validator.
   *
   * @var \Drupal\ipd_validator\Plugin\Validator\VnVnidValidator
   */
  protected ZmNrcValidator $validator;

  /**
   * Setup tests.
   */
  protected function setUp(): void {
    parent::setUp();

    $this->countryManager = $this->createMock(CountryManager::class);

    $this->validator = new ZmNrcValidator(
      [],
      'zm_nrc_validator',
      ['country_code' => 'ZM'],
      $this->countryManager
    );
  }

  /**
   * Test validator.
   *
   * @dataProvider documentProvider
   */
  public function testDocumentValidation(string $document, bool $expected): void {
    $this->assertSame($expected, $this->validator->isValid($document));
  }

  /**
   * Document provider.
   */
  public function documentProvider(): array {
    return [
      // ✅ Válidos
      ['123456789', TRUE],
      ['000000001', TRUE],
      ['999999999', TRUE],
      ['123-456-789', TRUE],
      ['123.456.789', TRUE],
      ['123 456 789', TRUE],
      ['123-456 789', TRUE],
      ['12-34.56 789', TRUE],
      ['1234 56789', TRUE],
      ['123456-789', TRUE],
    // Espacio.
      ['12 3456789', TRUE],

      // ❌ Inválidos
    // 8 dígitos
      ['12345678', FALSE],
    // 10 dígitos
      ['1234567890', FALSE],
    // Letra al final.
      ['12345678A', FALSE],
    // guión.
      ['1234567-9', FALSE],
      ['', FALSE],
    ];
  }

}
